@@ -129,7 +129,7 @@ class AssignmentClause(BaseClause):
     """ a single variable st statement """
 
     def __unicode__(self):
-        return u'"{}" = :{}'.format(self.field, self.context_id)
+        return u'"{}" = %({})s'.format(self.field, self.context_id)
 
     def insert_tuple(self):
         return self.field, self.context_id
@@ -170,15 +170,15 @@ class SetUpdateClause(ContainerUpdateClause):
         qs = []
         ctx_id = self.context_id
         if self.previous is None and not (self._assignments or self._additions or self._removals):
-            qs += ['"{}" = :{}'.format(self.field, ctx_id)]
+            qs += ['"{}" = %({})s'.format(self.field, ctx_id)]
         if self._assignments:
-            qs += ['"{}" = :{}'.format(self.field, ctx_id)]
+            qs += ['"{}" = %({})s'.format(self.field, ctx_id)]
             ctx_id += 1
         if self._additions:
-            qs += ['"{0}" = "{0}" + :{1}'.format(self.field, ctx_id)]
+            qs += ['"{0}" = "{0}" + %({1})s'.format(self.field, ctx_id)]
             ctx_id += 1
         if self._removals:
-            qs += ['"{0}" = "{0}" - :{1}'.format(self.field, ctx_id)]
+            qs += ['"{0}" = "{0}" - %({1})s'.format(self.field, ctx_id)]
 
         return ', '.join(qs)
 
@@ -232,15 +232,15 @@ class ListUpdateClause(ContainerUpdateClause):
         qs = []
         ctx_id = self.context_id
         if self._assignments is not None:
-            qs += ['"{}" = :{}'.format(self.field, ctx_id)]
+            qs += ['"{}" = %({})s'.format(self.field, ctx_id)]
             ctx_id += 1
 
         if self._prepend:
-            qs += ['"{0}" = :{1} + "{0}"'.format(self.field, ctx_id)]
+            qs += ['"{0}" = %({1})s + "{0}"'.format(self.field, ctx_id)]
             ctx_id += 1
 
         if self._append:
-            qs += ['"{0}" = "{0}" + :{1}'.format(self.field, ctx_id)]
+            qs += ['"{0}" = "{0}" + %({1})s'.format(self.field, ctx_id)]
 
         return ', '.join(qs)
 
@@ -355,10 +355,10 @@ class MapUpdateClause(ContainerUpdateClause):
 
         ctx_id = self.context_id
         if self.previous is None and not self._updates:
-            qs += ['"int_map" = :1']
+            qs += ['"int_map" = %({})s'.format(ctx_id)]
         else:
             for _ in self._updates or []:
-                qs += ['"{}"[:{}] = :{}'.format(self.field, ctx_id, ctx_id + 1)]
+                qs += ['"{}"[%({})s] = %({})s'.format(self.field, ctx_id, ctx_id + 1)]
                 ctx_id += 2
 
         return ', '.join(qs)
@@ -379,7 +379,7 @@ class CounterUpdateClause(ContainerUpdateClause):
     def __unicode__(self):
         delta = self.value - self.previous
         sign = '-' if delta < 0 else '+'
-        return '"{0}" = "{0}" {1} :{2}'.format(self.field, sign, self.context_id)
+        return '"{0}" = "{0}" {1} %({2})s'.format(self.field, sign, self.context_id)
 
 
 class BaseDeleteClause(BaseClause):
@@ -427,7 +427,7 @@ class MapDeleteClause(BaseDeleteClause):
 
     def __unicode__(self):
         if not self._analyzed: self._analyze()
-        return ', '.join(['"{}"[:{}]'.format(self.field, self.context_id + i) for i in range(len(self._removals))])
+        return ', '.join(['"{}"[%({})s]'.format(self.field, self.context_id + i) for i in range(len(self._removals))])
 
 
 class BaseCQLStatement(object):
@@ -625,7 +625,7 @@ class InsertStatement(AssignmentStatement):
 
         qs += ["({})".format(', '.join(['"{}"'.format(c) for c in columns]))]
         qs += ['VALUES']
-        qs += ["({})".format(', '.join([':{}'.format(v) for v in values]))]
+        qs += ["({})".format(', '.join(['%({})s'.format(v) for v in values]))]
 
         if self.ttl:
             qs += ["USING TTL {}".format(self.ttl)]
